==> deepin-system-monitor_1.0.0-1.tar.xz: deepin-system-monitor-1.4.8/translations/deepin-system-monitor_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>AttributesDialog</name>
    <message>
        <source>Process name</source>
        <translation>Nombre del proceso</translation>
    </message>
    <message>
        <source>Command line</source>
        <translation>Línea de comandos</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Hora de inicio</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
</context>
<context>
    <name>CompactDiskMonitor</name>
    <message>
        <source>Disk read</source>
        <translation>Lectura de disco</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Escritura en disco</translation>
    </message>
</context>
<context>
    <name>CompactMemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation>Memoria</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Intercambio</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Inactivo</translation>
    </message>
</context>
<context>
    <name>CompactNetworkMonitor</name>
    <message>
        <source>Download</source>
        <translation>Descarga</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Subida</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
</context>
<context>
    <name>DiskMonitor</name>
    <message>
        <source>Disk</source>
        <translation>Disco</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Lectura de disco</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Escritura en disco</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Force to end application</source>
        <translation>Forzar el cierre de la aplicación</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Tema oscuro</translation>
    </message>
    <message>
        <source>End application</source>
        <translation>Finalizar aplicación</translation>
    </message>
    <message>
        <source>Ending this application may cause data loss.
Are you sure to continue?</source>
        <translation>Finalizar esta aplicación ocasionaría pérdida de datos.
¿Está seguro de que desea continuar?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Compact mode</source>
        <translation>Modo compacto</translation>
    </message>
</context>
<context>
    <name>MemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation>Memoria</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Intercambio</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Inhabilitado</translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Network</source>
        <translation>Red</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Descarga</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Subida</translation>
    </message>
</context>
<context>
    <name>ProcessItem</name>
    <message>
        <source>No response</source>
        <translation>Sin respuesta</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
</context>
<context>
    <name>ProcessManager</name>
    <message>
        <source>End process</source>
        <translation>Finalizar proceso</translation>
    </message>
    <message>
        <source>Ending this process may cause data loss.
Are you sure to continue?</source>
        <translation>Finalizar este proceso ocasionaría pérdida de datos.
¿Está seguro de que desea continuar?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Suspender proceso</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Reanudar proceso</translation>
    </message>
    <message>
        <source>View process location</source>
        <translation>Ver ubicación del proceso</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propiedades</translation>
    </message>
    <message>
        <source>%2 applications and %3 processes are running</source>
        <translation>%2 aplicaciones y %3 procesos están en ejecución</translation>
    </message>
</context>
<context>
    <name>ProcessView</name>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memoria</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Escritura de disco</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Lectura de disco</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Descarga</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Subida</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Deepin System Monitor is an intuitive and powerful system monitor. It can monitor the process CPU, memory, network, disk and other status.</source>
        <translation>El monitor de sistema Deepin es un intuitivo y poderoso administrador de procesos y aplicaciones. Con él podrás supervisar el funcionamiento de la CPU, la memoria, la conexión a Internet, el disco y otras variables.</translation>
    </message>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Monitor del sistema Deepin</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Monitor del sistema Deepin</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Process initiation service</source>
        <translation>Entorno de escritorio Deepin - Proceso de servicio de inicialización</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Desktop</source>
        <translation>Entorno de escritorio Deepin - Escritorio</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Polkit proxy</source>
        <translation>Entorno de escritorio Deepin - Proxy de Polkit</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Launcher</source>
        <translation>Entorno de escritorio Deepin - Lanzador</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Dock</source>
        <translation>Entorno de escritorio Deepin - Muelle</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Screen display</source>
        <translation>Entorno de escritorio Deepin - Visualización de pantalla</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Daemon</source>
        <translation>Entorno de escritorio Deepin - Demonio</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session daemon</source>
        <translation>Entorno de escritorio Deepin - Demonio de sesión</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session initialization process</source>
        <translation>Entorno de escritorio Deepin - Proceso de inicialización de sesión</translation>
    </message>
    <message>
        <source>Deepin File Manager daemon</source>
        <translation>Entorno de escritorio Deepin - Gestor de archivos de Deepin</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Lock screen service</source>
        <translation>Entorno de escritorio Deepin - Servicio de bloqueo de pantalla</translation>
    </message>
    <message>
        <source>Deepin Window Manager </source>
        <translation>Gestor de ventanas Deepin</translation>
    </message>
    <message>
        <source>Deepin Window Manager switcher</source>
        <translation>Interruptor Gestor de ventanas Deepin</translation>
    </message>
    <message>
        <source>Deepin notification</source>
        <translation>Notificación de Deepin</translation>
    </message>
    <message>
        <source>Deepin Cloud Print agent</source>
        <translation>Agente de Deepin Cloud Print</translation>
    </message>
    <message>
        <source>Deepin menu service</source>
        <translation>Servicio del menú de Deepin</translation>
    </message>
    <message>
        <source>Deepin Store daemon</source>
        <translation>Demonio de Deepin Store</translation>
    </message>
    <message>
        <source>Window match daemon</source>
        <translation>Demonio de coincidencia de ventana</translation>
    </message>
    <message>
        <source>Window match daemon DBus service</source>
        <translation>Servicio DBus para el demonio de coincidencia de ventana</translation>
    </message>
    <message>
        <source>SSH agent</source>
        <translation>Agente SSH</translation>
    </message>
    <message>
        <source>User mode virtual file system daemon</source>
        <translation>Demonio del sistema virtual de archivos de User mode</translation>
    </message>
    <message>
        <source>Fuse server of user mode virtual file system daemon</source>
        <translation>Servidor Fuse del demonio del sistema virtual de archivos de User mode</translation>
    </message>
    <message>
        <source>Helper process of Deepin Store client</source>
        <translation>Proceso auxiliar del cliente de Deepin Store</translation>
    </message>
    <message>
        <source>Network manager</source>
        <translation>Administrador de conexiones</translation>
    </message>
    <message>
        <source>PolicyKit DBus service</source>
        <translation>Servicio DBus de PolicyKit</translation>
    </message>
    <message>
        <source>File sharing service daemon</source>
        <translation>Demonio del servicio para compartir archivos</translation>
    </message>
    <message>
        <source>X service</source>
        <translation>Servicio X</translation>
    </message>
    <message>
        <source>Fcitx input method</source>
        <translation>Método de entrada Fcitx</translation>
    </message>
    <message>
        <source>Fcitx input method DBus daemon</source>
        <translation>Demonio DBus del método de entrada Fctix</translation>
    </message>
    <message>
        <source>Sogou input method daemon</source>
        <translation>Demonio del método de entrada Sogou</translation>
    </message>
    <message>
        <source>ShadowSocks local client</source>
        <translation>Cliente local ShadowSocks</translation>
    </message>
    <message>
        <source>Sound service</source>
        <translation>Servicio de audio</translation>
    </message>
    <message>
        <source>Print daemon</source>
        <translation>Demonio de impresión</translation>
    </message>
    <message>
        <source>Light display manager</source>
        <translation>Administrador de pantalla lumínica</translation>
    </message>
    <message>
        <source>System service manager</source>
        <translation>Administrador del servicio del sistema</translation>
    </message>
    <message>
        <source>System service manager - Device management daemon</source>
        <translation>Administrador del servicio del sistema - Demonio de administración del dispositivo</translation>
    </message>
    <message>
        <source>Disk daemon</source>
        <translation>Demonio del disco</translation>
    </message>
    <message>
        <source>Account daemon</source>
        <translation>Demonio de la cuenta</translation>
    </message>
    <message>
        <source>DBus daemon</source>
        <translation>Demonio DBus</translation>
    </message>
    <message>
        <source>Mouse event daemon</source>
        <translation>Demonio de eventos del ratón</translation>
    </message>
    <message>
        <source>DConf service</source>
        <translation>Servicio DConf</translation>
    </message>
    <message>
        <source>Gnome keyring daemon</source>
        <translation>Demonio de llavero Gnome</translation>
    </message>
    <message>
        <source>Bluetooth daemon</source>
        <translation>Demonio de Bluethoot</translation>
    </message>
    <message>
        <source>Power daemon</source>
        <translation>Demonio de energía</translation>
    </message>
    <message>
        <source>Modem device manager</source>
        <translation>Administrador de módem moderna</translation>
    </message>
    <message>
        <source>System print tray service</source>
        <translation>Servicio de bandeja de impresión del sistema</translation>
    </message>
    <message>
        <source>Chrome browser sandbox</source>
        <translation>Caja de seguridad del navegador Chrome</translation>
    </message>
    <message>
        <source>Synaptics touchpad device daemon</source>
        <translation>Demonio del dispositivo de panel táctil Synaptics</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Intercambio</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Inactivo</translation>
    </message>
    <message>
        <source>Sogou input method</source>
        <translation>Método de entrada Sogou</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Haz clic a la aplicación que deseas finalizar</translation>
    </message>
</context>
<context>
    <name>StatusMonitor</name>
    <message>
        <source>Applications</source>
        <translation>Aplicaciones</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Mis procesos</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Todos los procesos</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Bandeja</translation>
    </message>
</context>
<context>
    <name>Toolbar</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
</context>
</TS>

==> deepin-system-monitor_1.4.3.orig.tar.xz: deepin-system-monitor-1.4.3/translations/deepin-system-monitor_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>AttributesDialog</name>
    <message>
        <source>Process name</source>
        <translation>Nombre del proceso</translation>
    </message>
    <message>
        <source>Command line</source>
        <translation>Línea de comandos</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Hora de inicio</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CompactDiskMonitor</name>
    <message>
        <source>Disk read</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk write</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CompactMemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Swap</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not enabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CompactNetworkMonitor</name>
    <message>
        <source>Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Total</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
</context>
<context>
    <name>DiskMonitor</name>
    <message>
        <source>Disk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk read</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk write</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Force to end application</source>
        <translation>Forzar el cierre de la aplicación</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Tema oscuro</translation>
    </message>
    <message>
        <source>End application</source>
        <translation>Finalizar aplicación</translation>
    </message>
    <message>
        <source>Ending this application may cause data loss.
Are you sure to continue?</source>
        <translation>Finalizar esta aplicación puede causar pérdida de datos.
¿Está seguro de que desea continuar?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Compact mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation>Memoria</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Intercambio</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Inhabilitado</translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Network</source>
        <translation>Red</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Descarga</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Total</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Subida</translation>
    </message>
</context>
<context>
    <name>ProcessItem</name>
    <message>
        <source>No response</source>
        <translation>Sin respuesta</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
</context>
<context>
    <name>ProcessManager</name>
    <message>
        <source>End process</source>
        <translation>Finalizar proceso</translation>
    </message>
    <message>
        <source>Ending this process may cause data loss.
Are you sure to continue?</source>
        <translation>Finalizar este proceso puede causar pérdida de datos.
¿Está seguro de que desea continuar?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Suspender proceso</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Reanudar proceso</translation>
    </message>
    <message>
        <source>View process location</source>
        <translation>Ver ubicación del proceso</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propiedades</translation>
    </message>
    <message>
        <source>%2 applications and %3 processes are running</source>
        <translation>%2 aplicaciones y %3 procesos están en ejecución</translation>
    </message>
</context>
<context>
    <name>ProcessView</name>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memoria</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Escritura de disco</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Lectura de disco</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Descarga</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Subida</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Deepin System Monitor is an intuitive and powerful system monitor. It can monitor the process CPU, memory, network, disk and other status.</source>
        <translation>El monitor de sistema Deepin es un intuitivo y poderoso administrador de procesos y aplicaciones. Con él podrás supervisar el funcionamiento de la CPU, la memoria, la conexión a Internet, el disco y otras variables.</translation>
    </message>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Monitor del sistema Deepin</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Monitor del sistema Deepin</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Process initiation service</source>
        <translation>Entorno de escritorio Deepin - Proceso de servicio de inicialización</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Desktop</source>
        <translation>Entorno de escritorio Deepin - Escritorio</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Polkit proxy</source>
        <translation>Entorno de escritorio Deepin - Proxy de Polkit</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Launcher</source>
        <translation>Entorno de escritorio Deepin - Lanzador</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Dock</source>
        <translation>Entorno de escritorio Deepin - Muelle</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Screen display</source>
        <translation>Entorno de escritorio Deepin - Visualización de pantalla</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Daemon</source>
        <translation>Entorno de escritorio Deepin - Demonio</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session daemon</source>
        <translation>Entorno de escritorio Deepin - Demonio de sesión</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session initialization process</source>
        <translation>Entorno de escritorio Deepin - Proceso de inicialización de sesión</translation>
    </message>
    <message>
        <source>Deepin File Manager daemon</source>
        <translation>Entorno de escritorio Deepin - Gestor de archivos de Deepin</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Lock screen service</source>
        <translation>Entorno de escritorio Deepin - Servicio de bloqueo de pantalla</translation>
    </message>
    <message>
        <source>Deepin Window Manager </source>
        <translation>Gestor de ventanas Deepin</translation>
    </message>
    <message>
        <source>Deepin Window Manager switcher</source>
        <translation>Interruptor Gestor de ventanas Deepin</translation>
    </message>
    <message>
        <source>Deepin notification</source>
        <translation>Notificación de Deepin</translation>
    </message>
    <message>
        <source>Deepin Cloud Print agent</source>
        <translation>Agente de Deepin Cloud Print</translation>
    </message>
    <message>
        <source>Deepin menu service</source>
        <translation>Servicio del menú de Deepin</translation>
    </message>
    <message>
        <source>Deepin Store daemon</source>
        <translation>Demonio de Deepin Store</translation>
    </message>
    <message>
        <source>Window match daemon</source>
        <translation>Demonio de coincidencia de ventana</translation>
    </message>
    <message>
        <source>Window match daemon DBus service</source>
        <translation>Servicio DBus para el demonio de coincidencia de ventana</translation>
    </message>
    <message>
        <source>SSH agent</source>
        <translation>Agente SSH</translation>
    </message>
    <message>
        <source>User mode virtual file system daemon</source>
        <translation>Demonio del sistema virtual de archivos de User mode</translation>
    </message>
    <message>
        <source>Fuse server of user mode virtual file system daemon</source>
        <translation>Servidor Fuse del demonio del sistema virtual de archivos de User mode</translation>
    </message>
    <message>
        <source>Helper process of Deepin Store client</source>
        <translation>Proceso auxiliar del cliente de Deepin Store</translation>
    </message>
    <message>
        <source>Network manager</source>
        <translation>Administrador de conexiones</translation>
    </message>
    <message>
        <source>PolicyKit DBus service</source>
        <translation>Servicio DBus de PolicyKit</translation>
    </message>
    <message>
        <source>File sharing service daemon</source>
        <translation>Demonio del servicio para compartir archivos</translation>
    </message>
    <message>
        <source>X service</source>
        <translation>Servicio X</translation>
    </message>
    <message>
        <source>Fcitx input method</source>
        <translation>Método de entrada Fcitx</translation>
    </message>
    <message>
        <source>Fcitx input method DBus daemon</source>
        <translation>Demonio DBus del método de entrada Fctix</translation>
    </message>
    <message>
        <source>Sogou input method daemon</source>
        <translation>Demonio del método de entrada Sogou</translation>
    </message>
    <message>
        <source>ShadowSocks local client</source>
        <translation>Cliente local ShadowSocks</translation>
    </message>
    <message>
        <source>Sound service</source>
        <translation>Servicio de audio</translation>
    </message>
    <message>
        <source>Print daemon</source>
        <translation>Demonio de impresión</translation>
    </message>
    <message>
        <source>Light display manager</source>
        <translation>Administrador de pantalla lumínica</translation>
    </message>
    <message>
        <source>System service manager</source>
        <translation>Administrador del servicio del sistema</translation>
    </message>
    <message>
        <source>System service manager - Device management daemon</source>
        <translation>Administrador del servicio del sistema - Demonio de administración del dispositivo</translation>
    </message>
    <message>
        <source>Disk daemon</source>
        <translation>Demonio del disco</translation>
    </message>
    <message>
        <source>Account daemon</source>
        <translation>Demonio de la cuenta</translation>
    </message>
    <message>
        <source>DBus daemon</source>
        <translation>Demonio DBus</translation>
    </message>
    <message>
        <source>Mouse event daemon</source>
        <translation>Demonio de eventos del ratón</translation>
    </message>
    <message>
        <source>DConf service</source>
        <translation>Servicio DConf</translation>
    </message>
    <message>
        <source>Gnome keyring daemon</source>
        <translation>Demonio de llavero Gnome</translation>
    </message>
    <message>
        <source>Bluetooth daemon</source>
        <translation>Demonio de Bluethoot</translation>
    </message>
    <message>
        <source>Power daemon</source>
        <translation>Demonio de energía</translation>
    </message>
    <message>
        <source>Modem device manager</source>
        <translation>Administrador de módem moderna</translation>
    </message>
    <message>
        <source>System print tray service</source>
        <translation>Servicio de bandeja de impresión del sistema</translation>
    </message>
    <message>
        <source>Chrome browser sandbox</source>
        <translation>Caja de seguridad del navegador Chrome</translation>
    </message>
    <message>
        <source>Synaptics touchpad device daemon</source>
        <translation>Demonio del dispositivo de panel táctil Synaptics</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Intercambio</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Inhabilitado</translation>
    </message>
    <message>
        <source>Sogou input method</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Haz clic a la aplicación que deseas finalizar</translation>
    </message>
</context>
<context>
    <name>StatusMonitor</name>
    <message>
        <source>Applications</source>
        <translation>Aplicaciones</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Mis procesos</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Todos los procesos</translation>
    </message>
</context>
<context>
    <name>Toolbar</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
</context>
</TS>
